/****************************************************************************
 *
 *  DRD - Robotic API ver 3.2
 *  Copyright (C) 2001-2010
 *  Force Dimension, Switzerland
 *  All Rights Reserved.
 *
 *  contact: support@forcedimension.com
 *
 ****************************************************************************/


/* C header */

#ifndef __DRDC_H__
#define __DRDC_H__

#include "dhdc.h"


/****************************************************************************
 *  OS DEPENDENCIES
 ****************************************************************************/

#if defined(WIN32) || defined(WIN64)
#ifndef __API
#define __API __stdcall
#endif
#endif

#ifndef __API
#define __API
#endif

#ifdef __cplusplus
extern "C" {
#endif


/****************************************************************************
 *  typedefs
 ****************************************************************************/

enum axis    { DRD_X = 0, DRD_Y, DRD_Z };
enum encoder { DRD_E0 = 0, DRD_E1, DRD_E2 };


/****************************************************************************
 *  API
 ****************************************************************************/

  int    __API drdOpen             ();
  int    __API drdOpenID           (int index);
  int    __API drdSetDevice        (char ID);
  int    __API drdGetDeviceID      ();
  int    __API drdClose            (char ID = -1);
  bool   __API drdIsRunning        (char ID = -1);
  bool   __API drdIsMoving         (char ID = -1);
  bool   __API drdIsFiltering      (char ID = -1);
  double __API drdGetTime          ();
  void   __API drdSleep            (double sec);
  void   __API drdWaitForTick      (char ID = -1);
  bool   __API drdIsInitialized    (char ID = -1);
  int    __API drdAutoInit         (char ID = -1);
  int    __API drdGetPos           (double *px, double *py, double *pz, char ID = -1);
  double __API drdGetCtrlFreq      (char ID = -1);
  int    __API drdStart            (char ID = -1);
  int    __API drdEnableFilter     (bool on, char ID = -1);
  int    __API drdMoveToPos        (double px, double py, double pz, bool block = true, char ID = -1);
  int    __API drdMoveToEnc        (int enc0, int enc1, int enc2, bool block = true, char ID = -1);
  int    __API drdTrackPos         (double px, double py, double pz, char ID = -1);
  int    __API drdTrackEnc         (int enc0, int enc1, int enc2, char ID = -1);
  int    __API drdHold             (char ID = -1);
  int    __API drdStop             (char ID = -1);
  int    __API drdSetPriorities    (int prio, int ctrlprio, char ID = -1);
  void   __API drdSetEncPGain      (double gain, char ID = -1);
  double __API drdGetEncPGain      (char ID = -1);
  int    __API drdSetEncMoveParam  (double  amax, double  vmax, double  jerk, char ID = -1);
  int    __API drdSetEncTrackParam (double  amax, double  vmax, double  jerk, char ID = -1);
  int    __API drdSetPosMoveParam  (double  amax, double  vmax, double  jerk, char ID = -1);
  int    __API drdSetPosTrackParam (double  amax, double  vmax, double  jerk, char ID = -1);
  int    __API drdGetEncMoveParam  (double *amax, double *vmax, double *jerk, char ID = -1);
  int    __API drdGetEncTrackParam (double *amax, double *vmax, double *jerk, char ID = -1);
  int    __API drdGetPosMoveParam  (double *amax, double *vmax, double *jerk, char ID = -1);
  int    __API drdGetPosTrackParam (double *amax, double *vmax, double *jerk, char ID = -1);


#ifdef __cplusplus
}
#endif


#endif
